#
# spec file for package mathomatic
#
# Copyright (c) 2019 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mathomatic
Version:        16.0.5
Release:        1.28
Summary:        Computer algebra system
License:        LGPL-2.1-or-later
Group:          Productivity/Scientific/Math
URL:            http://www.mathomatic.org/
Source:         http://mathomatic.orgserve.de/mathomatic-%{version}.tar.bz2
BuildRequires:  readline-devel
BuildRequires:  update-desktop-files
Requires:       m4

%description
Mathomatic is a free, portable, general-purpose Computer Algebra System (CAS)
that can automatically solve, differentiate, simplify, combine, and compare
algebraic equations, perform standard, complex number, modular, and polynomial
arithmetic, etc. It does some calculus and is very easy to learn and use.
Plotting expressions with gnuplot is also supported. This package
is complete, including Mathomatic, the Prime Number Tools, m4 Mathomatic,
and all documentation.

%package devel
Summary:        Development Package for Mathomatic
Group:          Development/Libraries/C and C++

%description devel
This package contains the Mathomatic symbolic math library, for using the
Mathomatic code inside of any C compatible program.  This is a static
library only, with no dependencies or requirements.  It has a small, easy
to use API that is written in C.  The Mathomatic code is not re-entrant.

%prep
%setup -q

%build
make OPTFLAGS="%{optflags}" %{?_smp_mflags} READLINE=1
make -C primes OPTFLAGS="%{optflags}" %{?_smp_mflags}
make -C lib %{?_smp_mflags} lib \
%if 0%{?suse_version} > 1500
OPTFLAGS="%{optflags} -g -ffat-lto-objects"
%else
OPTFLAGS="%{optflags} -g"
%endif

%install
make bininstall matho-rmath-install DESTDIR=%{buildroot} prefix=%{_prefix} docdir=%{_docdir} datadir=%{_datadir}
rm %{buildroot}%{_datadir}/pixmaps/mathomatic.{png,xpm}
install -m0644 icons/mathomatic.svg %{buildroot}%{_datadir}/pixmaps/%{name}.svg
%suse_update_desktop_file -n %{name}
make -C primes install DESTDIR=%{buildroot} prefix=%{_prefix}
make -C lib install DESTDIR=%{buildroot} prefix=%{_prefix} libdir=%{_libdir} includedir=%{_includedir}
make -C lib distclean

%check
make check
make -C primes check bigcheck

%files
%license COPYING
%doc examples tests
%doc README.txt AUTHORS NEWS doc
%{_mandir}/man1/mathomatic.1%{?ext_man}
%{_mandir}/man1/matho.1%{?ext_man}
%{_mandir}/man1/rmath.1%{?ext_man}
%{_mandir}/man1/matho-primes.1%{?ext_man}
%{_mandir}/man1/matho-pascal.1%{?ext_man}
%{_mandir}/man1/matho-sumsq.1%{?ext_man}
%{_mandir}/man1/primorial.1%{?ext_man}
%{_mandir}/man1/matho-mult.1%{?ext_man}
%{_mandir}/man1/matho-sum.1%{?ext_man}
%{_datadir}/%{name}
%{_bindir}/mathomatic
%{_bindir}/matho
%{_bindir}/rmath
%{_bindir}/matho-primes
%{_bindir}/matho-pascal
%{_bindir}/matho-sumsq
%{_bindir}/primorial
%{_bindir}/matho-mult
%{_bindir}/matho-sum
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.svg

%files devel
%doc lib
%{_mandir}/man3/matho_init.3%{?ext_man}
%{_mandir}/man3/matho_clear.3%{?ext_man}
%{_mandir}/man3/matho_parse.3%{?ext_man}
%{_mandir}/man3/matho_process.3%{?ext_man}
%{_libdir}/libmathomatic.a
%{_includedir}/mathomatic.h

%changelog
* Wed Nov 27 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 16.0.5
  * Corrected and improved "tests/finance.in" and the
    terminology used, thanks to Wolfram Alpha.
  * Fixed "./update" command (which updates "proto.h") to work
    without the readline development headers and libraries
    installed.
  * m4/gradians.m4 copied with m4/functions.m4, when installing
    with "make m4install" into "/usr/local/share/mathomatic/m4/",
    so gradian trig mode can be used by typing "rmath
    gradians.m4" at the shell prompt, while in that directory.
    The debug level was being set in degrees.m4 and gradians.m4;
    no longer.
  * Mathomatic now always runs "set load" after "set save",
    for the convenience of immediately loading the specified
    settings, and for error checking.
    From now on Mathomatic does not set the alarm nor hangup
    handlers, because it crashes the entire shell window when
    readline is compiled in and an alarm or hangup signal
    happens. Works acceptably now that these signal handlers are
    not set, it just quits when time is up, saying "Alarm clock";
    The same thing happens for SIGHUP, except it just says
    "Hangup" and quits.  I am really not liking readline nor its
    license now.
    SIGALRM and SIGHUP are no longer given handlers. The default
    seems to be what has to be there with the current readline
    mess.
    Overwriting the current signal handlers causes serious bugs,
    but only for readline.
  * Fixed "lib/compile.testmain" to work with the latest linker.
  * Made all output methods respect "set columns", so
    "display all >output.txt" will not always use infinite
    columns. This goes for the Symbolic Math Library, too.
- Re-enabled ppc64 build
- Dropped mathomatic.desktop as source
- Spec cleanup
* Wed Oct 23 2013 dvaleev@suse.com
- Exclude ppc64 from building. It have failing tests and upstream
  seems not interested in fixing that.
* Tue Sep 11 2012 georgegesslein@gmail.com
- Updated to Mathomatic 16.0.4, only change is to allow
  linking with editline library, instead of readline.
* Sat Sep  8 2012 georgegesslein@gmail.com
- Updated to new, enhanced version: Mathomatic 16.0.3
  All changes are listed at http://mathomatic.org/NEWS
* Mon Aug  6 2012 georgegesslein@gmail.com
- Updated to new bug fix version: Mathomatic 16.0.2
  All changes are listed at http://mathomatic.org/NEWS
* Sun Jul 22 2012 georgegesslein@gmail.com
- Updated to new version: Mathomatic 16.0.1
  All changes are listed at http://mathomatic.org/NEWS
* Fri Jun 29 2012 georgegesslein@gmail.com
- Updated to major new version, Mathomatic 16.0.0
  All changes are listed at http://mathomatic.org/NEWS
* Fri May 25 2012 georgegesslein@gmail.com
- Updated to latest Mathomatic version 15.8.5
  Features more user interface improvements and many bugfixes.
  All changes are listed at http://mathomatic.org/NEWS
* Thu May 10 2012 georgegesslein@gmail.com
- Updated to the latest Mathomatic version 15.8.4
  This release features bug fixes and interface improvements.
  All changes are listed at http://mathomatic.org/NEWS
* Sun Apr 29 2012 georgegesslein@gmail.com
- Updated to Mathomatic version 15.8.3
- Added matho_clear(3) man page.
- All other changes are listed at http://mathomatic.org/NEWS
* Sat Mar 24 2012 georgegesslein@gmail.com
- Updated to Mathomatic version 15.8.2
  This release fixes regressions and other bugs.
  All changes are listed at http://mathomatic.org/NEWS
* Fri Mar  9 2012 georgegesslein@gmail.com
- Updated to Mathomatic version 15.8.1
  This is a bugfix release
- Removed unnecessary INSTALL_PROGRAM=install from mathomatic.spec
- All other changes are listed at http://mathomatic.org/NEWS
* Sat Feb 18 2012 georgegesslein@gmail.com
- Updated to Mathomatic version 15.8.0.
  This is a bugfix release.
  All changes are listed at http://mathomatic.org/NEWS
* Wed Feb  1 2012 georgegesslein@gmail.com
- Updated to Mathomatic version 15.7.3.
  All changes are listed at http://mathomatic.org/NEWS
- Author's secondary email address changed from "gesslein@linux.com"
  to "gesslein@mathomatic.org".
* Wed Dec 14 2011 georgegesslein@gmail.com
- Updated to Mathomatic version 15.7.2.
  All changes are listed at http://mathomatic.org/NEWS
* Tue Nov 22 2011 cfarrell@suse.com
- Use SPDX format (http://www.spdx.org/licenses). Also, the package is
  LGPL-2.1 only
* Fri Nov 18 2011 georgegesslein@gmail.com
- Updated to Mathomatic version 15.7.1.
  All changes are listed here: http://mathomatic.org/NEWS
* Wed Nov  2 2011 georgegesslein@gmail.com
- Updated to Mathomatic version 15.7.0.
- Removed requirement for gnuplot.  (How do I suggest gnuplot?)
- All other changes are listed here: http://mathomatic.org/NEWS
* Sun Sep 25 2011 georgegesslein@gmail.com
- Updated to Mathomatic version 15.6.5.
  All changes are listed here: http://mathomatic.org/changes.txt
* Wed Aug 24 2011 georgegesslein@gmail.com
- Updated to version 15.6.4.
  All changes are listed here: http://mathomatic.org/changes.txt
* Thu Aug  4 2011 georgegesslein@gmail.com
- Updated to version 15.6.3.
* Sun Jun 12 2011 georgegesslein@gmail.com
- Remove requirement of time command availability.
* Sun Jun 12 2011 georgegesslein@gmail.com
- Updated to version 15.6.2 with corrected makefile.
* Sun Jun  5 2011 georgegesslein@gmail.com
- Updated to version 15.6.1
- Now installing m4/functions.m4 to proper directory
* Thu May 12 2011 georgegesslein@gmail.com
- RPM spec file corrections and cleanup
- added devel subpackage
* Sat Apr 30 2011 georgegesslein@gmail.com
- Update to version 15.6.0.  Removed default stripping of
  mathomatic executable.
* Tue Apr 19 2011 georgegesslein@gmail.com
- Update to version 15.5.3, added m4 Mathomatic.
* Mon Apr 18 2011 georgegesslein@gmail.com
- 15.5.2-3, added Prime Number Tools to install, in case someone
  wants them.  These are small, integer math utilities.
* Thu Apr 14 2011 georgegesslein@gmail.com
- 15.5.2-2, respect RPM_OPT_FLAGS
* Mon Mar 21 2011 georgegesslein@gmail.com
- Update to version 15.5.2
* Thu Mar 10 2011 georgegesslein@gmail.com
- Update to version 15.5.1.
* Sat Mar  5 2011 georgegesslein@gmail.com
- 15.5.0-3, a few fixes, fixed 64-bit build failures.
* Sat Mar  5 2011 georgegesslein@gmail.com
- 15.5.0-2, added Mathomatic static library install.
- Added mathomatic.desktop file, still doesn't seem to be in a
  proper category, but it is now completely configurable.
* Fri Feb 25 2011 georgegesslein@gmail.com
- New upstream version 15.5.0, with many ease-of-use enhancements.
- Stripped mathomatic executable.
* Fri Feb 18 2011 georgegesslein@gmail.com
- 15.4.4-3, Created this file "mathomatic.changes".
* Mon Feb 14 2011 georgegesslein@gmail.com
- Mathomatic version 15.4.4, Initial package.
